{"": "", "Total": "Insgesamt", "Disk space": "Speicherplatz", "Up one level": "Eine Ebene nach oben", "File name": "Dateiname", "All combined": "Alle zusammen", "Select this directory": "Dieses Verzeichnis ausw\u00e4hen", "File transfer": "Dateitransfer", "Filesystem": "Dateisystem", "Cancel": "Abbrechen", "Write to the filesystem": "Auf das Dateisystem schreiben", "Save": "Speichern", "Deleting": "L\u00f6sche", "Read from the filesystem": "Lese vom Dateisystem"}