{"": "", "Total": "Celkem", "Disk space": "M\u00edsto na disku", "Up one level": "Nad\u0159azen\u00fd adres\u00e1\u0159", "File name": "N\u00e1zev souboru", "All combined": "To v\u0161e dohromady", "Select this directory": "Zvolit tuto slo\u017eku", "File transfer": "P\u0159enos soubor\u016f", "Filesystem": "Souborov\u00fd syst\u00e9m", "Cancel": "Zru\u0161it", "Write to the filesystem": "Zapisovat do syst\u00e9mu soubor\u016f", "Save": "Ulo\u017eit", "Deleting": "Odstra\u0148ov\u00e1n\u00ed", "Read from the filesystem": "\u010cten\u00ed ze souborov\u00e9ho syst\u00e9mu"}