{"": "", "Total": "Total", "Disk space": "Espa\u00e7o em disco", "Up one level": "Subir um n\u00edvel", "File name": "Nome do arquivo", "All combined": "Tudo combinado", "Select this directory": "Selecione o diret\u00f3rio", "File transfer": "Transfer\u00eancia de arquivo", "Filesystem": "Arquivos do sistema", "Cancel": "Cancelar", "Write to the filesystem": "Escreva para o sistema de arquivos", "Save": "Salvar", "Deleting": "Apagando", "Read from the filesystem": "Ler a partir do sistema de arquivos"}