{"": "", "Total": "Teljes", "Disk space": "Lemezter\u00fclet", "Up one level": "Egy szinttel feljebb", "File name": "F\u00e1jln\u00e9v", "All combined": "Minden egyes\u00edtett", "Select this directory": "K\u00f6nyvt\u00e1r kiv\u00e1laszt\u00e1s", "File transfer": "F\u00e1jl\u00e1tvitel", "Filesystem": "F\u00e1jlrendszer", "Cancel": "M\u00e9gse", "Write to the filesystem": "F\u00e1jlrendszer \u00edr\u00e1s", "Save": "Ment\u00e9s", "Deleting": "T\u00f6rl\u00e9s", "Read from the filesystem": "F\u00e1jlrendszer olvas\u00e1s"}