{"": "", "Total": "Toplam", "Disk space": "Disk alan\u0131", "Up one level": "Bir \u00fcst dizin", "File name": "Dosya ad\u0131", "All combined": "Hepsi birle\u015ftirildi", "Select this directory": "Bu dizini se\u00e7", "File transfer": "Dosya transferi", "Filesystem": "Dosya sistemi", "Cancel": "\u0130ptal", "Write to the filesystem": "Dosya sistemine yaz", "Save": "Kaydet", "Deleting": "Siliniyor", "Read from the filesystem": "Dosya sisteminden oku"}