{"": "", "Total": "", "Disk space": "", "Up one level": "Prestavi se nivo vi\u0161je", "File name": "Ime datoteke", "All combined": "", "Select this directory": "Izberite to mapo", "File transfer": "Prenos datotek", "Filesystem": "", "Cancel": "Prekli\u010di", "Write to the filesystem": "Pi\u0161i v datote\u010dni sistem", "Save": "Shrani", "Deleting": "Brisanje", "Read from the filesystem": "Branje iz datote\u010dnega sistema"}