{"": "", "Total": "Total", "Disk space": "Espacio en disco", "Up one level": "Subir un nivel", "File name": "Nombre de fichero", "All combined": "Combinar todo", "Select this directory": "Seleccionar este directorio", "File transfer": "Transferir archivo", "Filesystem": "Sistema de archivos", "Cancel": "Cancelar", "Write to the filesystem": "Escribir en el sistema de archivos", "Save": "Guardar", "Deleting": "Eliminando", "Read from the filesystem": "Leer el sistema de archivos"}