{"": "", "Total": "Total", "Disk space": "Espace disque", "Up one level": "Remonter d'un niveau", "File name": "Nom du fichier", "All combined": "Tout", "Select this directory": "S\u00e9lectionnez ce r\u00e9pertoire", "File transfer": "Transfert de fichier", "Filesystem": "Syst\u00e8me de fichiers", "Cancel": "Annuler", "Write to the filesystem": "\u00c9crire dans le syst\u00e8me de fichiers", "Save": "Enregistrer", "Deleting": "Suppression en cours", "Read from the filesystem": "Lire \u00e0 partir du syst\u00e8me de fichiers"}