{"": "", "Total": "", "Disk space": "", "Up one level": "", "File name": "\ud30c\uc77c \uc774\ub984", "All combined": "", "Select this directory": "\uc774 \ud3f4\ub354\ub97c \uc120\ud0dd", "File transfer": "\ud30c\uc77c \uc804\uc1a1", "Filesystem": "", "Cancel": "\ucde8\uc18c", "Write to the filesystem": "\ud30c\uc77c \uc2dc\uc2a4\ud15c\uc5d0 \uc4f0\uae30", "Save": "\uc800\uc7a5", "Deleting": "\uc0ad\uc81c \uc911", "Read from the filesystem": "\ud30c\uc77c \uc2dc\uc2a4\ud15c\uc5d0\uc11c \uc77d\uae30"}