{"": "", "Total": "Totale", "Disk space": "Spazio sul disco", "Up one level": "Su di un livello", "File name": "Nome del file", "All combined": "Il tutto combinato", "Select this directory": "Selezionare la cartella", "File transfer": "Trasferimento file", "Filesystem": "Filesystem", "Cancel": "Annulla", "Write to the filesystem": "Scrivi nel filesystem", "Save": "Salva", "Deleting": "Eliminazione", "Read from the filesystem": "Leggi dal file System"}