{"": "", "Total": "Totaal", "Disk space": "Schijfruimte", "Up one level": "E\u00e9n niveau omhoog", "File name": "Bestandsnaam", "All combined": "Alle gecombineerd", "Select this directory": "Selecteer deze map", "File transfer": "Bestandsoverdracht", "Filesystem": "Bestandssysteem", "Cancel": "Annuleren", "Write to the filesystem": "Schrijven naar het bestandssysteem", "Save": "Opslaan", "Deleting": "Bezig met verwijderen", "Read from the filesystem": "Lezen van het bestandssysteem"}