{"": "", "Total": "", "Disk space": "", "Up one level": "W g\u00f3r\u0119 o jeden poziom", "File name": "Nazwa pliku", "All combined": "", "Select this directory": "Wybierz ten katalog", "File transfer": "Transfer plik\u00f3w", "Filesystem": "", "Cancel": "Anuluj", "Write to the filesystem": "Napisz do systemu plik\u00f3w", "Save": "Zapisz", "Deleting": "Usuwanie", "Read from the filesystem": "Odczytaj z systemu plik\u00f3w"}